@@ -1,6 +1,15 @@
-#line 1 "inc/Module/Install/WriteAll.pm - /usr/local/share/perl/5.8.4/Module/Install/WriteAll.pm"
+#line 1
 package Module::Install::WriteAll;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.63';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
 
 sub WriteAll {
     my $self = shift;
@@ -12,22 +21,20 @@ sub WriteAll {
         @_
     );
 
-    $self->sign(1) if $args{sign};
-    $self->Meta->write if $args{meta};
+    $self->sign(1)                if $args{sign};
+    $self->Meta->write            if $args{meta};
     $self->admin->WriteAll(%args) if $self->is_admin;
 
-    if ($0 =~ /Build.PL$/i) {
+    if ( $0 =~ /Build.PL$/i ) {
         $self->Build->write;
-    }
-    else {
+    } else {
         $self->check_nmake if $args{check_nmake};
-        $self->makemaker_args( PL_FILES => {} )
-            unless $self->makemaker_args->{'PL_FILES'};
-
+        unless ( $self->makemaker_args->{'PL_FILES'} ) {
+        	$self->makemaker_args( PL_FILES => {} );
+        }
         if ($args{inline}) {
             $self->Inline->write;
-        }
-        else {
+        } else {
             $self->Makefile->write;
         }
     }
